X-Git-Url: https://scm.cri.ensmp.fr/git/linpy.git/blobdiff_plain/9b755b94aa2c8847ffca607de239f5c3bca9984b..cc1d83eaadffc1d5de296e2ec2b401d04de70c41:/setup.py
diff --git a/setup.py b/setup.py
index f72af50..f3f62c1 100755
--- a/setup.py
+++ b/setup.py
@@ -2,31 +2,43 @@
# Copyright 2014 MINES ParisTech
#
# This file is part of Linpy.
#
# Linpy is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Linpy is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with Linpy. If not, see .
+# along with LinPy. If not, see .
-from distutils.core import setup, Extension
+from distutils.core import Extension, setup
+
+
+with open('linpy/_version.py') as file:
+ __version__ = None
+ exec(file.read())
+
+with open('README.rst') as file:
+ long_description = file.read()
setup(
- name='pypol',
- description='A polyhedral library based on ISL',
+ name='LinPy',
+ version=__version__,
+ license='GPLv3',
+ description='A polyhedral library based on isl',
+ long_description=long_description,
author='MINES ParisTech',
- packages=['pypol'],
- ext_modules = [
- Extension('pypol._islhelper',
- sources=['pypol/_islhelper.c'],
- libraries=['isl'])
+ url='https://scm.cri.mines-paristech.fr/git/linpy.git',
+ packages=['linpy'],
+ ext_modules=[
+ Extension('linpy._islhelper',
+ sources=['linpy/_islhelper.c'],
+ libraries=['isl'])
]
)
@@ -2,31 +2,43 @@
# Copyright 2014 MINES ParisTech
#
-# This file is part of Linpy.
+# This file is part of LinPy.
#
@@ -2,31 +2,43 @@
#
-# Linpy is free software: you can redistribute it and/or modify
+# LinPy is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
@@ -2,31 +2,43 @@
# (at your option) any later version.
#
-# Linpy is distributed in the hope that it will be useful,
+# LinPy is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the